@@ -5,18 +5,27 @@ class Person(KinopoiskObject):
 
     name = ''
     name_original = ''
+    information = ''
 
     year_birth = None
 
+    photos = []
+
     def __init__(self, **kwargs):
         super(Person, self).__init__(**kwargs)
-        from sources import PersonLink, PersonMainPage # import here for successful installing via pip
+        from sources import PersonLink, PersonMainPage, PersonPhotosPage # import here for successful installing via pip
         self.register_source('link', PersonLink)
         self.register_source('main_page', PersonMainPage)
+        self.register_source('photos', PersonPhotosPage)
         self.posters = self.audience = []
 
+        self.set_url('info', '/handler_info.php?obj_type=actor&obj_id=%d')
+
     def __repr__(self):
-        return '%s (%s), %s' % (self.name, self.name_original, self.year_birth)
+        return ('<%s (%s), %s>' % (self.name, self.name_original, self.year_birth or '-')).encode('utf-8')
+
+    def get_photos(self):
+        return self.photos
 
 class PersonManager(Manager):
     '''
@@ -36,4 +45,4 @@ class PersonManager(Manager):
             'm_act[find]': query,
         })
 
-Person.objects = PersonManager()
\ No newline at end of file
+Person.objects = PersonManager()
