@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+from BeautifulSoup import BeautifulSoup
 import re
 
 def get_request(url, params=None):
@@ -97,13 +98,13 @@ class KinopoiskObject(object):
     def set_url(self, name, url):
         self._urls[name] = url
 
-    def get_url(self, name):
+    def get_url(self, name, postfix=''):
         url = self._urls.get(name)
         if not url:
             raise ValueError('There is no urlpage with name "%s"' % name)
         if not self.id:
             raise ValueError('ID of object is empty')
-        return 'http://www.kinopoisk.ru' + url % self.id
+        return 'http://www.kinopoisk.ru' + url % self.id + postfix
 
     def set_source(self, name):
         if name not in self._sources:
@@ -113,10 +114,23 @@ class KinopoiskObject(object):
         class_name = self._source_classes.get(name)
         if not class_name:
             raise ValueError('There is no source with name "%s"' % name)
-        return class_name()
+        instance = class_name()
+        instance.content_name = name
+        return instance
+
+class KinopoiskImage(KinopoiskObject):
+
+    def __init__(self, id=None):
+        super(KinopoiskImage, self).__init__(id)
+        self.set_url('picture', '/picture/%d/')
+
+    def get_url(self, name='picture', postfix=''):
+        return super(KinopoiskImage, self).get_url(name, postfix)
 
 class KinopoiskPage(object):
 
+    content_name = None
+
     def prepare_str(self, value):
         value = re.compile(r"&nbsp;").sub(" ", value)
         value = re.compile(r"&#151;").sub(" - ", value)
@@ -140,7 +154,62 @@ class KinopoiskPage(object):
         return content
 
     def get(self, instance):
+        if instance.id:
+            response = get_request(instance.get_url(self.content_name))
+            content = response.content.decode('windows-1251', 'ignore')
+#            content = content[content.find('<div style="padding-left: 20px">'):content.find('        </td></tr>')]
+            self.parse(instance, content)
+            return
         raise NotImplementedError('This method must be implemented in subclass')
 
     def parse(self, instance, content):
-        raise NotImplementedError('You must implement KinopoiskPage.parse() method')
\ No newline at end of file
+        raise NotImplementedError('You must implement KinopoiskPage.parse() method')
+
+class KinopoiskImagesPage(KinopoiskPage):
+    '''
+    Parser of kinopoisk images page
+    '''
+    field_name = None
+
+    def get(self, instance, page=1):
+        response = get_request(instance.get_url(self.content_name, postfix='page/%d/' % page))
+        content = response.content.decode('windows-1251', 'ignore')
+
+        # header with sign 'No posters'
+        if re.findall(r'<h1 class="main_title">', content):
+            return False
+
+        content = content[content.find('<div style="padding-left: 20px">'):content.find('        </td></tr>')]
+
+        soup_content = BeautifulSoup(content)
+        table = soup_content.findAll('table', attrs={'class': re.compile('^fotos')})
+        if table:
+            self.parse(instance, unicode(table[0]))
+            # may be there is more pages?
+            if len(getattr(instance, self.field_name)) % 21 == 0:
+                try:
+                    self.get(instance, page+1)
+                except ValueError:
+                    return
+        else:
+            raise ValueError('Parse error. Do not found posters for movie %s' % (instance.get_url('posters')))
+
+    def parse(self, instance, content):
+        urls = getattr(instance, self.field_name, [])
+
+        links = BeautifulSoup(content).findAll('a')
+        for link in links:
+
+            img_id = re.compile(r'/picture/(\d+)/').findall(link['href'])
+            picture = KinopoiskImage(int(img_id[0]))
+
+            response = get_request(picture.get_url())
+            content = response.content.decode('windows-1251', 'ignore')
+            img = BeautifulSoup(content).find('img', attrs={'id': 'image'})
+            if img:
+                img_url = img['src']
+                if img_url not in urls:
+                    urls.append(img_url)
+
+        setattr(instance, self.field_name, urls)
+        instance.set_source(self.content_name)
\ No newline at end of file
